
#include<arpa/inet.h>
#include<netinet/in.h>

#include<netdb.h>
#include<stdio.h>
#include<stdlib.h>



unsigned long resolvename(char *name)
{
static struct hostent *ht;

if((ht = gethostbyname(name))==NULL){
   #ifdef RESOLV_DEBUG
   fprintf(stderr,"RESOLV: resovname(): following names cannot be solved. %s\n", name);
   #endif
   return 0;
   }
return *((unsigned long *)ht->h_addr_list[0]);
}


int main(int argc, char * argv[])
{
struct sockaddr_in my_addr;

if(argc != 2){
   fprintf(stderr,"resolv Ver1.0\n");
   fprintf(stderr,"resolv <URL>\n");
   exit(1);
   }

my_addr.sin_addr.s_addr = resolvename(argv[1]);
printf("%s\n", inet_ntoa(my_addr.sin_addr));

return 0;
}







